ShardCacheDirectClient

Struct ShardCacheDirectClient 

pub struct ShardCacheDirectClient { /* private fields */ }
Blocking SCNP client that automatically routes each key to its shard port.

Implementations

Source

impl ShardCacheDirectClient

pub fn connect(addr: impl ToSocketAddrs, shard_count: usize) -> Result<Self>

Connects to every shard-owned port starting at addr.

addr must be the first direct shard port, not the fanout port.

pub fn connect_with_route_mode( addr: impl ToSocketAddrs, shard_count: usize, route_mode: ShardCacheRouteMode, ) -> Result<Self>

Connects to every shard-owned port using an explicit route mode.

pub fn get_into(&mut self, key: &[u8], out: &mut Vec<u8>) -> Result<bool>

Reads key from its owning shard into out, returning true on hit.

pub fn set(&mut self, key: &[u8], value: &[u8]) -> Result<()>

Sets key on its owning shard.

pub fn set_ex(&mut self, key: &[u8], value: &[u8], ttl_ms: u64) -> Result<()>

Sets key on its owning shard with a millisecond TTL.

pub fn get_ex_into( &mut self, key: &[u8], ttl_ms: u64, out: &mut Vec<u8>, ) -> Result<bool>

Reads key from its owning shard into out and sets a millisecond TTL.

pub fn del(&mut self, key: &[u8]) -> Result<bool>

Deletes key from its owning shard.

pub fn exists(&mut self, key: &[u8]) -> Result<bool>

Returns whether key exists on its owning shard.

pub fn ttl(&mut self, key: &[u8]) -> Result<i64>

Returns Redis-compatible TTL seconds for key on its owning shard.

pub fn expire(&mut self, key: &[u8], ttl_ms: u64) -> Result<bool>

Sets a millisecond TTL on key on its owning shard.

pub fn scan_shard_resp_into( &mut self, shard_id: usize, cursor: u64, count: usize, out: &mut Vec<u8>, ) -> Result<bool>

Runs a shard-local SCNP scan on one direct shard connection. Callers can invoke this for different shards from different threads for parallel scans.